@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from __future__ import annotations
 
 import typing
@@ -8,13 +9,33 @@ V = typing.TypeVar("V")
 _DATA_PROXY_SLOTS = ("__data_obj__", "__bool_hook__")
 
 
+class _EmptyChainProxy:
+    """Class for mocking initial ChainProxy when we met first None object"""
+
+    __slots__ = ()
+
+    def get_value(self, *, default: typing.Optional[V] = None) -> typing.Union[T, V]:
+        if not self and default is not None:
+            return default
+        return None
+
+    def __getattr__(self, attr: str):
+        return self
+
+    def __bool__(self) -> bool:
+        return False
+
+
+_empty_chain = _EmptyChainProxy()
+
+
 class ChainProxy(typing.Generic[T]):
     """
     `ChainProxy` container:
-        * stores `data_object`
-        * proxying `data_object` attribute value into new `ChainProxy` instance
-        when attribute is invoked. If attribute does not exist or attribute value is `None`
-        `ChainProxy` instance `data_object` will be `None` and `bool_hook` will be `False`.
+    * stores `data_object`
+    * proxying `data_object` attribute value into new `ChainProxy` instance
+      when attribute is invoked. If attribute does not exist or attribute value is `None`
+      `ChainProxy` instance `data_object` will be `None` and `bool_hook` will be `False`.
 
     `ChainProxy` instance always returning when attribute is invoked
 
@@ -35,10 +56,7 @@ class ChainProxy(typing.Generic[T]):
         object_attribute = getattr(self.__data_obj__, attr, None)
 
         if object_attribute is None:
-            return ChainProxy(
-                typing.cast(T, object_attribute),
-                bool_hook=False,
-            )
+            return typing.cast(ChainProxy, _empty_chain)
 
         return ChainProxy(object_attribute, bool_hook=True)
 
@@ -51,7 +69,7 @@ class ChainProxy(typing.Generic[T]):
         return self.__bool_hook__
 
     def __repr__(self) -> str:
-        return f"DataProxy(data_object={self.__data_obj__}, bool_hook={self.__bool_hook__})"
+        return f"ChainProxy(data_object={self.__data_obj__}, bool_hook={self.__bool_hook__})"
 
     def __str__(self) -> str:
         return f"data_object={self.__data_obj__}, bool_hook={self.__bool_hook__}"
